@@ -1434,8 +1434,12 @@ excel_parse_formula1 (MSContainer const *container,
 			if (ver >= MS_BIFF_V8) {
 				cols++;
 				rows++;
-			} else if (cols == 0)
-				cols = 256;
+			} else {
+				if (cols == 0)
+					cols = 256;
+				if (rows == 0)
+					rows = 1; /* ??? */
+			}
 
 			v = value_new_array (cols, rows);
 
@@ -1752,7 +1756,11 @@ excel_parse_formula1 (MSContainer const *container,
 					sheet = nexpr->pos.sheet;
 					if (sheet == NULL)
 						sheet = ms_container_sheet (container);
+				} else if (sheet == XL_EXTERNSHEET_MAGIC_DELETED) {
+					/* What?  Happens for #752179.  */
+					sheet = NULL;
 				}
+
 				name = gnm_expr_new_name (nexpr, sheet, NULL);
 			}
 
